## $Id: test_browser.py 12371 2015-01-03 07:38:07Z henrik $
##
## Copyright (C) 2014 Uli Fouquet & Henrik Bettermann
## This program is free software; you can redistribute it and/or modify
## it under the terms of the GNU General Public License as published by
## the Free Software Foundation; either version 2 of the License, or
## (at your option) any later version.
##
## This program is distributed in the hope that it will be useful,
## but WITHOUT ANY WARRANTY; without even the implied warranty of
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
## GNU General Public License for more details.
##
## You should have received a copy of the GNU General Public License
## along with this program; if not, write to the Free Software
## Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
##
"""
Product browser and functional tests.
"""
import os
import grok
import datetime
from cStringIO import StringIO
from zope.component import queryUtility, getUtility
from zope.event import notify
from zope.interface.verify import verifyObject, verifyClass
from waeup.ikoba.products.tests.test_batching import ProductImportExportSetup
from ikobacustom.pcn.products.product import PCNProduct
from ikobacustom.pcn.products.export import PCNProductExporter
from ikobacustom.pcn.products.batching import PCNProductProcessor
from ikobacustom.pcn.testing import FunctionalLayer


class ProductImportExportTest(ProductImportExportSetup):

    layer = FunctionalLayer

    def setup_for_export(self):
        product = PCNProduct()
        product.product_id = u'LIC'
        product.valid_from = datetime.date(2015, 12, 4)
        self.app['products'][product.product_id] = self.product = product
        self.outfile = os.path.join(self.workdir, 'myoutput.csv')
        return

    def test_export_reimport_all(self):
        # we can export all products in a portal
        # set values we can expect in export file
        self.setup_for_export()
        exporter = PCNProductExporter()
        exporter.export_all(self.app, self.outfile)
        result = open(self.outfile, 'rb').read()
        self.assertEqual(result,
            'contract_category,contract_title,options,'
            'product_id,terms_and_conditions,title,valid_from,valid_to,users_with_local_roles\r\n'
            'license,,[],LIC,,Unnamed,2015-12-04#,,[]\r\n')
        # We can import the same file.
        processor = PCNProductProcessor()
        result = processor.doImport(
            self.outfile,
            ['contract_category','contract_title', 'options,', 'product_id',
            'terms_and_conditions','title','valid_from','valid_to','users_with_local_roles'],
            mode='create')
        num, num_fail, finished_path, failed_path = result
        #content = open(failed_path).read()
        # The object exists.
        self.assertEqual(num_fail,1)
        # We remove the original product.
        del self.app['products']['LIC']
        result = processor.doImport(
            self.outfile,
            ['contract_category','contract_title', 'options,', 'product_id',
            'terms_and_conditions','title','valid_from','valid_to','users_with_local_roles'],
            mode='create')
        num, num_fail, finished_path, failed_path = result
        self.assertEqual(num_fail,0)
        # We can import the same file in update mode.
        processor = PCNProductProcessor()
        result = processor.doImport(
            self.outfile,
            ['contract_category','contract_title', 'options,', 'product_id',
            'terms_and_conditions','title','valid_from','valid_to','users_with_local_roles'],
            mode='update')
        num, num_fail, finished_path, failed_path = result
        self.assertEqual(num,1)
        self.assertEqual(num_fail,0)
        return